@@ -1,21 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (c) 2001 Hans Petter Bieker <bieker@kde.org>
-   Copyright (c) 2012, 2013 Chusslove Illich <caslav.ilic@gmx.net>
+/*  This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2001 Hans Petter Bieker <bieker@kde.org>
+    SPDX-FileCopyrightText: 2012, 2013 Chusslove Illich <caslav.ilic@gmx.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <stdlib.h>
@@ -23,7 +10,7 @@
 #include "gettext.h"
 #include "config.h"
 
-#include <qstandardpaths.h>
+#include <QStandardPaths>
 #include <QByteArray>
 #include <QCoreApplication>
 #include <QDebug>
@@ -36,6 +23,8 @@
 
 #include <kcatalog_p.h>
 
+#include "ki18n_logging.h"
+
 // not defined on win32 :(
 #ifdef _WIN32
 #ifndef LC_MESSAGES
@@ -116,6 +105,35 @@ KCatalog::~KCatalog()
     delete d;
 }
 
+#if defined(Q_OS_ANDROID) && QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+static QString androidUnpackCatalog(const QString &relpath)
+{
+    // the catalog files are no longer extracted to the local file system
+    // by androiddeployqt starting with Qt 5.14, libintl however needs
+    // local files rather than qrc: or asset: URLs, so we unpack the .mo
+    // files on demand to the local cache folder
+
+    const QString cachePath = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/org.kde.ki18n/") + relpath;
+    QFileInfo cacheFile(cachePath);
+    if (cacheFile.exists()) {
+        return cachePath;
+    }
+
+    const QString assetPath = QLatin1String("assets:/share/locale/") + relpath;
+    if (!QFileInfo::exists(assetPath)) {
+        return {};
+    }
+
+    QDir().mkpath(cacheFile.absolutePath());
+    QFile f(assetPath);
+    if (!f.copy(cachePath)) {
+        qCWarning(KI18N) << "Failed to copy catalog:" << f.errorString() << assetPath << cachePath;
+        return {};
+    }
+    return cachePath;
+}
+#endif
+
 QString KCatalog::catalogLocaleDir(const QByteArray &domain,
                                    const QString &language)
 {
@@ -136,19 +154,27 @@ QString KCatalog::catalogLocaleDir(const QByteArray &domain,
         }
     }
 
-    QString file = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                          QStringLiteral("locale/") + relpath);
+#if defined(Q_OS_ANDROID)
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+// The exact file name must be returned on Android because libintl-lite loads a catalog by filename with bindtextdomain()
+    QString file = QDir::homePath()+QStringLiteral("/../qt-reserved-files/share/locale/") + relpath;
+    if (!QFile::exists(file)) {
+        file.clear();
+    }
+    return file;
+#else
+    return androidUnpackCatalog(relpath);
+#endif
+#else
+    const QString file = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("locale/") + relpath);
+
     QString localeDir;
     if (!file.isEmpty()) {
-#if defined(Q_OS_ANDROID)
-        // The exact file name must be returned on Android because libintl-lite loads a catalog by filename with bindtextdomain()
-        localeDir = file;
-#else
         // Path of the locale/ directory must be returned.
         localeDir = QFileInfo(file.left(file.size() - relpath.size())).absolutePath();
-#endif
     }
     return localeDir;
+#endif
 }
 
 QSet<QString> KCatalog::availableCatalogLanguages(const QByteArray &domain_)
@@ -167,10 +193,10 @@ QSet<QString> KCatalog::availableCatalogLanguages(const QByteArray &domain_)
     }
 
     QSet<QString> availableLanguages;
-    foreach (const QString &localDirPath, localeDirPaths) {
+    for (const QString &localDirPath : qAsConst(localeDirPaths)) {
         QDir localeDir(localDirPath);
-        QStringList languages = localeDir.entryList(QDir::AllDirs | QDir::NoDotAndDotDot);
-        foreach (const QString &language, languages) {
+        const QStringList languages = localeDir.entryList(QDir::AllDirs | QDir::NoDotAndDotDot);
+        for (const QString &language : languages) {
             QString relPath = QStringLiteral("%1/LC_MESSAGES/%2.mo")
                               .arg(language, domain);
             if (localeDir.exists(relPath)) {
@@ -196,7 +222,7 @@ void KCatalogPrivate::setupGettextEnv()
     if (language != currentLanguage || !bindDone) {
         Q_ASSERT_X(QCoreApplication::instance(), "KCatalogPrivate::setupGettextEnv", "You need to instantiate a Q*Application before using KCatalog");
         if (!QCoreApplication::instance()) {
-            qWarning() << "KCatalog being used without a Q*Application instance. Some translations won't work";
+            qCWarning(KI18N) << "KCatalog being used without a Q*Application instance. Some translations won't work";
         }
 
         currentLanguage = language;
