@@ -1,31 +1,18 @@
 /*
- *   Copyright 2013 Marco Martin <mart@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2013 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 // Undefine this because we don't want our i18n*() method names to be turned into i18nd*()
 #undef TRANSLATION_DOMAIN
 
 #include "klocalizedcontext.h"
 
-#include <QDebug>
-
 #include <klocalizedstring.h>
 
+#include "ki18n_logging.h"
+
 class KLocalizedContextPrivate
 {
 public:
@@ -78,7 +65,7 @@ static void subsVariant(KLocalizedString &trMessage, const QVariant &value)
                 trMessage = trMessage.subs(value.toString());
             } else {
                 trMessage = trMessage.subs(QStringLiteral("???"));
-                qWarning() << "couldn't convert" << value << "to translate";
+                qCWarning(KI18N) << "couldn't convert" << value << "to translate";
             }
 
     }
@@ -120,7 +107,7 @@ static void resolveMessage(KLocalizedString &trMessage,
     }
 }
 
-static void resolvePlural(KLocalizedString &trMessage, const QVariant param)
+static void resolvePlural(KLocalizedString &trMessage, const QVariant &param)
 {
     trMessage = trMessage.subs(param.toInt());
 }
@@ -130,7 +117,7 @@ QString KLocalizedContext::i18n(const QString &message,
                                 const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (message.isEmpty()) {
-        qWarning() << "i18n() needs at least one parameter";
+        qCWarning(KI18N) << "i18n() needs at least one parameter";
         return QString();
     }
 
@@ -152,7 +139,7 @@ QString KLocalizedContext::i18nc(const QString &context, const QString &message,
                                  const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (context.isEmpty() || message.isEmpty()) {
-        qWarning() << "i18nc() needs at least two arguments";
+        qCWarning(KI18N) << "i18nc() needs at least two arguments";
         return QString();
     }
 
@@ -174,7 +161,7 @@ QString KLocalizedContext::i18np(const QString &singular, const QString &plural,
                                  const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (singular.isEmpty() || plural.isEmpty()) {
-        qWarning() << "i18np() needs at least two arguments";
+        qCWarning(KI18N) << "i18np() needs at least two arguments";
         return QString();
     }
 
@@ -197,7 +184,7 @@ QString KLocalizedContext::i18ncp(const QString &context, const QString &singula
                                   const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (context.isEmpty() || singular.isEmpty() || plural.isEmpty()) {
-        qWarning() << "i18ncp() needs at least three arguments";
+        qCWarning(KI18N) << "i18ncp() needs at least three arguments";
         return QString();
     }
 
@@ -220,7 +207,7 @@ QString KLocalizedContext::i18nd(const QString &domain, const QString &message,
                                  const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (domain.isEmpty() || message.isEmpty()) {
-        qWarning() << "i18nd() needs at least two parameters";
+        qCWarning(KI18N) << "i18nd() needs at least two parameters";
         return QString();
     }
 
@@ -236,7 +223,7 @@ QString KLocalizedContext::i18ndc(const QString &domain, const QString &context,
                                   const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (domain.isEmpty() || context.isEmpty() || message.isEmpty()) {
-        qWarning() << "i18ndc() needs at least three arguments";
+        qCWarning(KI18N) << "i18ndc() needs at least three arguments";
         return QString();
     }
 
@@ -252,7 +239,7 @@ QString KLocalizedContext::i18ndp(const QString &domain, const QString &singular
                                   const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (domain.isEmpty() || singular.isEmpty() || plural.isEmpty()) {
-        qWarning() << "i18ndp() needs at least three arguments";
+        qCWarning(KI18N) << "i18ndp() needs at least three arguments";
         return QString();
     }
 
@@ -269,7 +256,7 @@ QString KLocalizedContext::i18ndcp(const QString &domain, const QString &context
                                    const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (domain.isEmpty() || context.isEmpty() || singular.isEmpty() || plural.isEmpty()) {
-        qWarning() << "i18ndcp() needs at least four arguments";
+        qCWarning(KI18N) << "i18ndcp() needs at least four arguments";
         return QString();
     }
 
@@ -288,7 +275,7 @@ QString KLocalizedContext::xi18n(const QString &message,
                                 const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (message.isEmpty()) {
-        qWarning() << "xi18n() needs at least one parameter";
+        qCWarning(KI18N) << "xi18n() needs at least one parameter";
         return QString();
     }
 
@@ -310,7 +297,7 @@ QString KLocalizedContext::xi18nc(const QString &context, const QString &message
                                  const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (context.isEmpty() || message.isEmpty()) {
-        qWarning() << "xi18nc() needs at least two arguments";
+        qCWarning(KI18N) << "xi18nc() needs at least two arguments";
         return QString();
     }
 
@@ -332,7 +319,7 @@ QString KLocalizedContext::xi18np(const QString &singular, const QString &plural
                                  const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (singular.isEmpty() || plural.isEmpty()) {
-        qWarning() << "xi18np() needs at least two arguments";
+        qCWarning(KI18N) << "xi18np() needs at least two arguments";
         return QString();
     }
 
@@ -355,7 +342,7 @@ QString KLocalizedContext::xi18ncp(const QString &context, const QString &singul
                                   const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (context.isEmpty() || singular.isEmpty() || plural.isEmpty()) {
-        qWarning() << "xi18ncp() needs at least three arguments";
+        qCWarning(KI18N) << "xi18ncp() needs at least three arguments";
         return QString();
     }
 
@@ -378,7 +365,7 @@ QString KLocalizedContext::xi18nd(const QString &domain, const QString &message,
                                  const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (domain.isEmpty() || message.isEmpty()) {
-        qWarning() << "xi18nd() needs at least two parameters";
+        qCWarning(KI18N) << "xi18nd() needs at least two parameters";
         return QString();
     }
 
@@ -394,7 +381,7 @@ QString KLocalizedContext::xi18ndc(const QString &domain, const QString &context
                                   const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (domain.isEmpty() || context.isEmpty() || message.isEmpty()) {
-        qWarning() << "x18ndc() needs at least three arguments";
+        qCWarning(KI18N) << "x18ndc() needs at least three arguments";
         return QString();
     }
 
@@ -410,7 +397,7 @@ QString KLocalizedContext::xi18ndp(const QString &domain, const QString &singula
                                   const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (domain.isEmpty() || singular.isEmpty() || plural.isEmpty()) {
-        qWarning() << "xi18ndp() needs at least three arguments";
+        qCWarning(KI18N) << "xi18ndp() needs at least three arguments";
         return QString();
     }
 
@@ -427,7 +414,7 @@ QString KLocalizedContext::xi18ndcp(const QString &domain, const QString &contex
                                    const QVariant &param6, const QVariant &param7, const QVariant &param8, const QVariant &param9, const QVariant &param10) const
 {
     if (domain.isEmpty() || context.isEmpty() || singular.isEmpty() || plural.isEmpty()) {
-        qWarning() << "xi18ndcp() needs at least four arguments";
+        qCWarning(KI18N) << "xi18ndcp() needs at least four arguments";
         return QString();
     }
 
